@@ -4,11 +4,13 @@ from typing import Tuple, Optional
 from gazpacho import Soup
 from returns.pipeline import flow
 from returns.pointfree import bind
+from returns.result import safe
+
 from scrapers.utils import find_one, find_many
 
 from models.Car import CarDate, CarFull, FuelType, BodyType, Drivetrain
 
-
+@safe
 def scrape_inchcape_car_detail(html: str) -> CarFull:
     soup = Soup(html)
 
