@@ -1,6 +1,8 @@
 import unittest
 import os
 
+from returns.result import Success
+
 from models.Car import CarFull, CarDate
 from scrapers.details.mollerAuto import scrape_moller_car_detail
 
@@ -10,7 +12,7 @@ THIS_FOLDER = os.path.dirname(os.path.abspath(__file__))
 class UtilsTestCase(unittest.TestCase):
     def test_audi(self) -> None:
         with open(os.path.join(THIS_FOLDER, "moller_data/moller_audi.html")) as car:
-            self.assertEqual(CarFull(
+            self.assertEqual(Success(CarFull(
                 url="https://lietotiauto.mollerauto.lv/lv/vehicle/10236564/audi-a4-20-tfsi-110kw-aut-20-110kw-aut/",
                 previewImgSrc='https://lietotiauto.mollerauto.lv/lv/vehicle/simage/10237323/10237323.jpg',
                 summary='Audi A4 2.0 TFSI 110kw aut. 2.0 110kW aut',
@@ -32,11 +34,11 @@ class UtilsTestCase(unittest.TestCase):
                 doors='4/5',
                 country="lv",
                 dealer="moller-auto"
-            ), scrape_moller_car_detail(car.read()))
+            )), scrape_moller_car_detail(car.read()))
 
     def test_audi_a6_sport(self) -> None:
         with open(os.path.join(THIS_FOLDER, "moller_data/moller_audi_a6_sport.html")) as car:
-            self.assertEqual(CarFull(
+            self.assertEqual(Success(CarFull(
                 url="https://lietotiauto.mollerauto.lv/lv/vehicle/10236087/audi-a6-sport-20-150kw-aut/",
                 previewImgSrc='https://lietotiauto.mollerauto.lv/lv/vehicle/simage/10236092/10236092.jpg',
                 summary='Audi A6 Sport 2.0 150kW aut',
@@ -58,11 +60,11 @@ class UtilsTestCase(unittest.TestCase):
                 doors='4/5',
                 country="lt",
                 dealer="moller-auto"
-            ), scrape_moller_car_detail(car.read()))
+            )), scrape_moller_car_detail(car.read()))
 
     def test_vw_amarok(self) -> None:
         with open(os.path.join(THIS_FOLDER, "moller_data/moller_vw_amarok.html")) as car:
-            self.assertEqual(CarFull(
+            self.assertEqual(Success(CarFull(
                 url="https://lietotiauto.mollerauto.lv/lv/vehicle/10235196/volkswagen-amarok-20-106kw-meh/",
                 previewImgSrc='https://lietotiauto.mollerauto.lv/lv/vehicle/simage/10236919/10236919.jpg',
                 summary='Volkswagen Amarok 2.0 106kW meh',
@@ -84,7 +86,7 @@ class UtilsTestCase(unittest.TestCase):
                 doors='4/5',
                 country="ee",
                 dealer="moller-auto"
-            ), scrape_moller_car_detail(car.read()))
+            )), scrape_moller_car_detail(car.read()))
 
 if __name__ == '__main__':
     unittest.main()
